"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk = require("chalk");
const cli_utils_1 = require("@ionic/cli-utils");
const TYPE_CHOICES = ['component', 'directive', 'page', 'pipe', 'provider', 'tabs'];
let GenerateCommand = class GenerateCommand extends cli_utils_1.Command {
    preRun(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const [config, project] = yield Promise.all([this.env.config.load(), this.env.project.load()]);
            if (project.type !== 'ionic-angular') {
                throw this.exit('Generators are only supported in Ionic Angular projects.');
            }
            const hooks = this.env.hooks.getRegistered('command:generate');
            if (hooks.length === 0) {
                const plugin = yield cli_utils_1.promptToInstallProjectPlugin(this.env, {
                    message: `To use generators, you need to install ${chalk.green('@ionic/cli-plugin-ionic-angular')}. Install and continue?`,
                });
                if (plugin) {
                    cli_utils_1.installPlugin(this.env, plugin);
                }
                else {
                    return 1;
                }
            }
            if (!inputs[0]) {
                const generatorType = yield this.env.prompt({
                    type: 'list',
                    name: 'generatorType',
                    message: 'What would you like to generate:',
                    choices: TYPE_CHOICES,
                });
                inputs[0] = generatorType;
            }
            if (!inputs[1]) {
                const generatorName = yield this.env.prompt({
                    type: 'input',
                    name: 'generatorName',
                    message: 'What should the name be?',
                    validate: v => cli_utils_1.validators.required(v, 'name')
                });
                inputs[1] = generatorName;
            }
            if (!this.env.flags.interactive && inputs[0] === 'tabs') {
                this.env.log.error(`Cannot generate tabs without prompts. Run without ${chalk.green('--no-interactive')}.`);
                return 1;
            }
        });
    }
    run(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const [type, name] = inputs;
            yield this.env.hooks.fire('command:generate', { cmd: this, env: this.env, inputs, options });
            this.env.log.ok(`Generated a ${chalk.bold(type)}${type === 'tabs' ? ' page' : ''} named ${chalk.bold(name)}!`);
        });
    }
};
GenerateCommand = tslib_1.__decorate([
    cli_utils_1.CommandMetadata({
        name: 'generate',
        type: 'project',
        description: `Generate pipes, components, pages, directives, providers, and tabs ${chalk.bold(`(ionic-angular >= 3.0.0)`)}`,
        longDescription: `
Automatically create components for your Ionic app.

The given ${chalk.green('name')} is normalized into an appropriate naming convention. For example, ${chalk.green('ionic generate page neat')} creates a page by the name of ${chalk.green('NeatPage')} in ${chalk.green('src/pages/neat/')}.
  `,
        exampleCommands: ['', ...TYPE_CHOICES, 'component foo', 'page Login', 'pipe MyFilterPipe'],
        inputs: [
            {
                name: 'type',
                description: `The type of generator (e.g. ${TYPE_CHOICES.map(t => chalk.green(t)).join(', ')})`,
                validators: [cli_utils_1.contains(TYPE_CHOICES, {})],
            },
            {
                name: 'name',
                description: 'The name of the component being generated',
            }
        ],
    })
], GenerateCommand);
exports.GenerateCommand = GenerateCommand;
