"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const os = require("os");
const path = require("path");
const chalk = require("chalk");
const cli_utils_1 = require("@ionic/cli-utils");
let SSHSetupCommand = class SSHSetupCommand extends cli_utils_1.Command {
    run(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const sshconfigPath = path.resolve(os.homedir(), '.ssh', 'config');
            const sshPath = path.resolve(os.homedir(), '.ssh');
            const keyPath = path.resolve(sshPath, 'ionic_rsa');
            const pubkeyPath = path.resolve(sshPath, 'ionic_rsa.pub');
            this.env.log.info('The automatic SSH setup will do the following:\n' +
                `1) Generate SSH key pair with OpenSSH.\n` +
                `2) Upload the generated SSH public key to our server, registering it on your account.\n` +
                `3) Modify your SSH config (${chalk.bold(cli_utils_1.prettyPath(sshconfigPath))}) to use the generated SSH private key for our server(s).`);
            const confirm = yield this.env.prompt({
                type: 'confirm',
                name: 'confirm',
                message: 'May we proceed?',
            });
            if (!confirm) {
                return 1;
            }
            yield this.runcmd(['ssh', 'generate', keyPath]);
            yield this.runcmd(['ssh', 'add', pubkeyPath]);
            yield this.runcmd(['ssh', 'use', keyPath]);
        });
    }
};
SSHSetupCommand = tslib_1.__decorate([
    cli_utils_1.CommandMetadata({
        name: 'setup',
        type: 'global',
        backends: [cli_utils_1.BACKEND_PRO],
        description: 'Setup your Ionic SSH keys automatically',
    })
], SSHSetupCommand);
exports.SSHSetupCommand = SSHSetupCommand;
