"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = require("path");
const minimist = require("minimist");
const chalk = require("chalk");
const cli_utils_1 = require("@ionic/cli-utils");
const commands_1 = require("./commands");
const init_1 = require("./lib/init");
const modules_1 = require("./lib/modules");
exports.name = 'ionic';
exports.version = '3.6.0-pro.4b58f416';
exports.namespace = new commands_1.IonicNamespace();
exports.meta = { filePath: __filename };
const BUILD_BEFORE_HOOK = 'build:before';
const BUILD_BEFORE_SCRIPT = `ionic:${BUILD_BEFORE_HOOK}`;
const BUILD_AFTER_HOOK = 'build:after';
const BUILD_AFTER_SCRIPT = `ionic:${BUILD_AFTER_HOOK}`;
const WATCH_BEFORE_HOOK = 'watch:before';
const WATCH_BEFORE_SCRIPT = `ionic:${WATCH_BEFORE_HOOK}`;
function registerHooks(hooks) {
    hooks.register(exports.name, 'command:config:set', ({ env, inputs, options, valueChanged }) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        let [p, v] = inputs;
        const { global } = options;
        if (global) {
            const config = yield env.config.load();
            if (p === 'backend' && valueChanged) {
                if (v === 'pro') {
                    config.urls.api = 'https://api.ionicjs.com';
                    config.urls.dash = 'https://dashboard.ionicjs.com';
                }
                else if (v === 'legacy') {
                    config.urls.api = 'https://api.ionic.io';
                    config.urls.dash = 'https://apps.ionic.io';
                }
                const wasLoggedIn = yield env.session.isLoggedIn();
                yield env.session.logout();
                if (wasLoggedIn) {
                    env.log.info('You have been logged out.');
                }
            }
        }
    }));
    hooks.register(exports.name, BUILD_BEFORE_HOOK, ({ env }) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const packageJson = yield env.project.loadPackageJson();
        if (packageJson.scripts && packageJson.scripts[BUILD_BEFORE_SCRIPT]) {
            env.log.debug(`Invoking ${chalk.cyan(BUILD_BEFORE_SCRIPT)} npm script.`);
            yield env.shell.run('npm', ['run', BUILD_BEFORE_SCRIPT], { showExecution: true });
        }
    }));
    hooks.register(exports.name, BUILD_AFTER_HOOK, ({ env }) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const packageJson = yield env.project.loadPackageJson();
        if (packageJson.scripts && packageJson.scripts[BUILD_AFTER_SCRIPT]) {
            env.log.debug(`Invoking ${chalk.cyan(BUILD_AFTER_SCRIPT)} npm script.`);
            yield env.shell.run('npm', ['run', BUILD_AFTER_SCRIPT], { showExecution: true });
        }
    }));
    hooks.register(exports.name, WATCH_BEFORE_HOOK, ({ env }) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const packageJson = yield env.project.loadPackageJson();
        if (packageJson.scripts && packageJson.scripts[WATCH_BEFORE_SCRIPT]) {
            env.log.debug(`Invoking ${chalk.cyan(WATCH_BEFORE_SCRIPT)} npm script.`);
            yield env.shell.run('npm', ['run', WATCH_BEFORE_SCRIPT], { showExecution: true });
        }
    }));
    hooks.register(exports.name, 'command:info', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const osName = modules_1.load('os-name');
        const os = osName();
        const node = process.version;
        const [npm, xcode, iosDeploy, iosSim,] = yield Promise.all([
            cli_utils_1.getCommandInfo('npm', ['-v']),
            cli_utils_1.getCommandInfo('/usr/bin/xcodebuild', ['-version']),
            cli_utils_1.getCommandInfo('ios-deploy', ['--version']),
            cli_utils_1.getCommandInfo('ios-sim', ['--version']),
        ]);
        return [
            { type: 'global-packages', name: 'Ionic CLI', version: exports.version },
            { type: 'system', name: 'Node', version: node },
            { type: 'system', name: 'npm', version: npm || 'not installed' },
            { type: 'system', name: 'OS', version: os },
            { type: 'system', name: 'Xcode', version: xcode || 'not installed' },
            { type: 'system', name: 'ios-deploy', version: iosDeploy || 'not installed' },
            { type: 'system', name: 'ios-sim', version: iosSim || 'not installed' },
        ];
    }));
}
exports.registerHooks = registerHooks;
function run(pargv, env) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const now = new Date();
        let exitCode = 0;
        let err;
        pargv = init_1.modifyArguments(pargv.slice(2));
        env['IONIC_CLI_LIB'] = __filename;
        const ienv = yield cli_utils_1.generateIonicEnvironment(exports, pargv, env);
        registerHooks(ienv.hooks);
        try {
            const configData = yield ienv.config.load();
            if (env['IONIC_EMAIL'] && env['IONIC_PASSWORD']) {
                ienv.log.debug(`${chalk.bold('IONIC_EMAIL')} / ${chalk.bold('IONIC_PASSWORD')} environment variables detected`);
                if (configData.user.email !== env['IONIC_EMAIL']) {
                    ienv.log.debug(`${chalk.bold('IONIC_EMAIL')} mismatch with current session--attempting login`);
                    try {
                        yield ienv.session.login(env['IONIC_EMAIL'], env['IONIC_PASSWORD']);
                    }
                    catch (e) {
                        ienv.log.error(`Error occurred during automatic login via ${chalk.bold('IONIC_EMAIL')} / ${chalk.bold('IONIC_PASSWORD')} environment variables.`);
                        throw e;
                    }
                }
            }
            if (ienv.project.directory) {
                const nodeModulesExists = yield cli_utils_1.pathExists(path.join(ienv.project.directory, 'node_modules'));
                if (!nodeModulesExists) {
                    const confirm = yield ienv.prompt({
                        type: 'confirm',
                        name: 'confirm',
                        message: `Looks like a fresh checkout! No ${chalk.green('./node_modules')} directory found. Would you like to install project dependencies?`,
                    });
                    if (confirm) {
                        ienv.log.info('Installing dependencies may take several minutes!');
                        const [installer, ...installerArgs] = yield cli_utils_1.pkgManagerArgs(ienv, { command: 'install' });
                        yield ienv.shell.run(installer, installerArgs, {});
                    }
                }
            }
            const argv = minimist(pargv, { boolean: true });
            argv._ = argv._.map(i => String(i));
            const foundCommand = init_1.mapLegacyCommand(argv._[0]);
            if (foundCommand) {
                ienv.log.msg(`The ${chalk.green(argv._[0])} command has been renamed. To find out more, run:\n\n` +
                    `  ${chalk.green(`ionic ${foundCommand} --help`)}\n\n`);
            }
            else {
                let updates;
                try {
                    yield cli_utils_1.loadPlugins(ienv);
                }
                catch (e) {
                    if (e.fatal) {
                        throw e;
                    }
                    ienv.log.error(chalk.red.bold('Error occurred while loading plugins. CLI functionality may be limited.\nChecking for CLI updates now...'));
                    ienv.log.debug(chalk.red(chalk.bold('Plugin error: ') + (e.stack ? e.stack : e)));
                    updates = yield cli_utils_1.checkForUpdates(ienv);
                    if (updates.length === 0) {
                        ienv.log.error('No updates found after plugin error--please report this issue.');
                    }
                }
                yield ienv.hooks.fire('plugins:init', { env: ienv });
                if (typeof updates === 'undefined' && now.getTime() - new Date(configData.lastCommand).getTime() >= 3600000) {
                    yield cli_utils_1.checkForUpdates(ienv);
                }
                const r = yield exports.namespace.runCommand(ienv, pargv);
                if (typeof r === 'number') {
                    exitCode = r;
                }
                configData.lastCommand = now.toISOString();
            }
        }
        catch (e) {
            ienv.log.debug(chalk.red.bold('!!! ERROR ENCOUNTERED !!!'));
            err = e;
        }
        try {
            yield Promise.all([ienv.config.save(), ienv.project.save()]);
        }
        catch (e) {
            ienv.log.error(e);
        }
        if (err) {
            ienv.tasks.fail();
            exitCode = 1;
            if (cli_utils_1.isValidationErrorArray(err)) {
                for (let e of err) {
                    ienv.log.error(e.message);
                }
                ienv.log.msg(`Use the ${chalk.green('--help')} flag for more details.`);
            }
            else if (cli_utils_1.isSuperAgentError(err)) {
                ienv.log.msg(cli_utils_1.formatSuperAgentError(err));
            }
            else if (err.fatal) {
                exitCode = typeof err.exitCode === 'number' ? err.exitCode : 1;
                if (err.message) {
                    if (exitCode > 0) {
                        ienv.log.error(err.message);
                    }
                    else {
                        ienv.log.msg(err.message);
                    }
                }
            }
            else {
                ienv.log.msg(chalk.red(String(err)));
                if (err.stack) {
                    ienv.log.debug(chalk.red(err.stack));
                }
            }
        }
        ienv.close();
        if (exitCode > 0) {
            process.exit(exitCode);
        }
    });
}
exports.run = run;
